@@ -2,25 +2,28 @@
 # this code is essentially the same as
 # the first example in howto/pb-usage
 
+from __future__ import print_function
+
 from twisted.spread import pb
-from twisted.internet import reactor
+from twisted.internet import reactor, endpoints
 
 def gotObject(object):
-    print "got object:", object
+    print("got object:", object)
     object.callRemote("getUser","moshez").addCallback(gotData)
 # or
 #   object.callRemote("getUsers").addCallback(gotData)
-   
+
 def gotData(data):
-    print 'server sent:', data
+    print('server sent:', data)
     reactor.stop()
-    
+
 def gotNoObject(reason):
-    print "no object:",reason
+    print("no object:",reason)
     reactor.stop()
 
 factory = pb.PBClientFactory()
-reactor.connectTCP("127.0.0.1",8889, factory)
+clientEndpoint = endpoints.clientFromString("tcp:127.0.0.1:8889")
+clientEndpoint.connect(factory)
 factory.getRootObject().addCallbacks(gotObject,gotNoObject)
 reactor.run()
-                                    
+
